import { PDFDocumentProxy } from 'pdfjs-dist';
import { Highlight, PdfScaleValue, PdfSelection } from '../types';
interface PdfHighlighterProps {
    containerElem: HTMLDivElement | null;
    highlights: Array<Highlight>;
    onScrollAway?(): void;
    pdfScaleValue?: PdfScaleValue;
    onSelection?(PdfSelection: PdfSelection, done?: (id: number) => void, revert?: () => void): void;
    selectionPopover?: any;
    enableAreaSelection?(event: MouseEvent): boolean;
    mouseSelectionStyle?: any;
    pdfDocument: PDFDocumentProxy;
    textSelectionColor?: string;
    style?: any;
    enableAreaHighlight?: boolean;
    enableEditing?: boolean;
    enableHighlights?: boolean;
}
declare class PdfHighlighter {
    private props;
    private enableAreaHighlight;
    private enableEditing;
    private enableHighlights;
    private highlights;
    private popover;
    private highlightBindings;
    private highlightLayerBindings;
    private ghostHighlight;
    private selection;
    private scrolledToHighlightId;
    private isAreaSelectionInProgress;
    private isEditInProgress;
    private updatePopoverPosition;
    private contextMenu;
    private currentScaleValue;
    private eventBusPdfJs;
    private linkServicePdfJs;
    private resizeObserver;
    private pdfViewer;
    private mouseSelectionComponent;
    constructor(props: PdfHighlighterProps);
    private initializeViewer;
    private copyTextSelection;
    private destroyHighlightLayers;
    private initAreaHighlight;
    private onElementContextMenu;
    private handleTextSelection;
    private clearTextSelection;
    toggleEditing: (flag?: boolean) => void;
    toggleHighlights: (flag?: boolean) => void;
    private handleScroll;
    private destroyContextMenu;
    private renderHighlightLayer;
    private handleScaleValue;
    initialize(): void;
    /**
     * Render highlight layers for all pages
     */
    renderHighlightLayers: () => void;
    /**
     * Scroll to a highlight
     * @param highlight - The highlight to scroll to
     */
    scrollToHighlight: (highlight: Highlight) => void;
    scrollToPage: (pageNumber: number) => void;
    /**
     * Set the scale of the PDF Viewer.
     * accepted values are `auto`, `page-fit`, `page-width`, or a number (1 means 100%).
     */
    setScale: (scaleValue: PdfScaleValue) => void;
    updateHighlights: (highlights: Array<Highlight>) => void;
    getHighlights: () => Highlight[];
}
export { PdfHighlighter };
